# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2025-04-08

### Added
- Initial release of F1 MCP Server
- Support for retrieving F1 race calendar, event information
- Driver information and telemetry data access
- Session results and analysis features
- Performance comparison between drivers
- Championship standings retrieval
- Support for both stdio and SSE transport mechanisms
